Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

All Classes Files Functions Typedefs Modules Pages
ranges::v3::range_access::RandomAccessCursorConcept Member List

This is the complete list of members for ranges::v3::range_access::RandomAccessCursorConcept, including all inherited members.

base_concepts_t typedef (defined in ranges::v3::concepts::refines< BidirectionalCursorConcept >) | ranges::v3::concepts::refines< BidirectionalCursorConcept > |
refines()=delete (defined in ranges::v3::concepts::refines< BidirectionalCursorConcept >) | ranges::v3::concepts::refines< BidirectionalCursorConcept > |
requires_(T &&t) -> decltype(concepts::valid_expr(concepts::model_of< concepts::SignedIntegral >(t.distance_to(t)),(t.advance(t.distance_to(t)), concepts::void_))) (defined in ranges::v3::range_access::RandomAccessCursorConcept) | ranges::v3::range_access::RandomAccessCursorConcept |
requires_(Ts &&...) (defined in ranges::v3::concepts::refines< BidirectionalCursorConcept >) | ranges::v3::concepts::refines< BidirectionalCursorConcept > |